@@ -1,5 +1,5 @@
 /**
- *	JFractionLab
+*	JFractionLab
  *	Copyright (C) 2005 jochen georges, gnugeo _ at _ gnugeo _ dot _ de
  *
  *	This program is free software: you can redistribute it and/or modify
@@ -57,28 +57,37 @@ import jfractionlab.exerciseDialogs.DivideFractionsByFractions;
 import jfractionlab.exerciseDialogs.DivideFractionsByNumbers;
 import jfractionlab.exerciseDialogs.DivideNumbersByFractions;
 import jfractionlab.exerciseDialogs.ExtendFraction;
+import jfractionlab.exerciseDialogs.FractionToDecimal;
 import jfractionlab.exerciseDialogs.ImproperFraction;
 import jfractionlab.exerciseDialogs.MixedNumbers;
 import jfractionlab.exerciseDialogs.MultiplyFractions;
 import jfractionlab.exerciseDialogs.NameFraction;
 import jfractionlab.exerciseDialogs.PlusAndMinus;
 import jfractionlab.exerciseDialogs.ReduceFraction;
-import jfractionlab.jflOptionDialogs.AdditionWorkSheetDialog;
-import jfractionlab.jflOptionDialogs.InfoDialog;
-import jfractionlab.jflOptionDialogs.LogSaverDialog;
-import jfractionlab.jflOptionDialogs.MultiplicationWorksheetDialog;
-
-
+import jfractionlab.jflDialogs.ConfigurePDFLATEXDialog;
+import jfractionlab.jflDialogs.InfoDialog;
+import jfractionlab.jflDialogs.LogSaverDialog;
+import jfractionlab.jflDialogs.WorkSheetDialogAddition;
+import jfractionlab.jflDialogs.WorkSheetDialogDivision;
+import jfractionlab.jflDialogs.WorkSheetDialogExtending;
+import jfractionlab.jflDialogs.WorkSheetDialogImproperFractions;
+import jfractionlab.jflDialogs.WorkSheetDialogMixedNumbers;
+import jfractionlab.jflDialogs.WorkSheetDialogMultiplication;
+import jfractionlab.jflDialogs.WorkSheetDialogReducing;
+import jfractionlab.jflDialogs.WorkSheetDialogSubtraction;
+import jfractionlab.logtable.LogTable;
 
 //TODO jfractionlab.JFractionLab
-//
-// worksheets als pdf 
-// pdflatex fuer windows
-// eigene aufgaben beim kuerzen
-// worksheets als *odt"
-// neuer aufgabentyp: vergleichen durch gleichnamig machen
-// "fraction-calculator"
-// spiel 1 und 2 : auch "falsche pizzen" anzeigen und auch andere formen anzeigen
+//help chapter fraction to decimal
+//help chapter how to make worksheets
+
+
+//windows: confFile schreiben (class properties?)-> pfad zu pdflatex in conffile schreiben -> worksheetgenerator winpdflatex aktivieren
+
+//neuer aufgabentyp: vergleichen durch gleichnamig machen?
+
+//worksheets und worksheet-dialogs aufraeumen - besseres design
+//worksheets als odt
 
 //document the code with javadoc
 
@@ -96,14 +105,15 @@ public class JFractionLab extends JFrame implements ActionListener, ItemListener
 		private JMenuItem jmiPortuguese = new JMenuItem("");
 //		private JMenuItem jmiPolish = new JMenuItem("");
 	private JMenu jmWorkSheet = new JMenu("");
-//		private JMenuItem jmiExtendingWorkSheet = new JMenuItem("");
-//		private JMenuItem jmiReducingWorkSheet = new JMenuItem("");
-//		private JMenuItem jmiImproperFractionsWorkSheet = new JMenuItem("");
-//		private JMenuItem jmiMixedNumbersWorkSheet = new JMenuItem("");
-		private JMenuItem jmiAdditionWorkSheet = new JMenuItem("");
-//		private JMenuItem jmiSubtractionWorkSheet = new JMenuItem("");
-		private JMenuItem jmiMultiplicationWorkSheet = new JMenuItem("");
-//		private JMenuItem jmiDivisionWorkSheet = new JMenuItem("");
+		private JMenuItem jmiWorkSheetExtending = new JMenuItem("");
+		private JMenuItem jmiWorkSheetReducing = new JMenuItem("");
+		private JMenuItem jmiWorkSheetImproperFractions = new JMenuItem("");
+		private JMenuItem jmiWorkSheetMixedNumbers = new JMenuItem("");
+		private JMenuItem jmiWorkSheetAddition = new JMenuItem("");
+		private JMenuItem jmiWorkSheetSubtraction = new JMenuItem("");
+		private JMenuItem jmiWorkSheetMultiplication = new JMenuItem("");
+		private JMenuItem jmiWorkSheetDivision = new JMenuItem("");
+		private JMenuItem jmiConfigurePDFLatex;
 	private JMenu jmHelp = new JMenu("");
 	private static JCheckBoxMenuItem cb_showtippatstart = new JCheckBoxMenuItem();
 	private JMenuItem jmiAbout = new JMenuItem("");
@@ -124,6 +134,8 @@ public class JFractionLab extends JFrame implements ActionListener, ItemListener
 	private PointDisplay dsp_improperFractions = new PointDisplay(true);
 	private JButton btn_mixedNumbers;
 	private PointDisplay dsp_mixedNumbers = new PointDisplay(true);
+	private JButton btn_fractionToDecimal;
+	private PointDisplay dsp_fractionToDecimal = new PointDisplay(true);
 	private TitledBorder brd_bottom;
 	private JButton btn_addFractions;
 	private PointDisplay dsp_addFractions = new PointDisplay(true);
@@ -144,6 +156,7 @@ public class JFractionLab extends JFrame implements ActionListener, ItemListener
 	private static final int location_y=100;
 	private static final int size_x=1000;
 	private static final int size_y=300;
+	public static String os;
 	
 	public int points_clickNumerator = 0; //points in spiel 1 und korrekt bergeben?
 	public int points_nameFraction = 0;
@@ -153,6 +166,7 @@ public class JFractionLab extends JFrame implements ActionListener, ItemListener
 	public int points_reduceFraction = 0;
 	public int points_unechteBrueche = 0;
 	public int points_gemischteZahlen = 0;
+	public int points_fractionToDecimal = 0;
 	public int points_addFractions = 0;
 	public int points_subtractFractions = 0;
 	public int points_multiplyFractions = 0;
@@ -162,7 +176,7 @@ public class JFractionLab extends JFrame implements ActionListener, ItemListener
 	
 	//Damit alle Dialoge dieselbe Schrift haben, ist sie hier static definiert.
 	public static Font infofont = new Font("SansSerif",Font.BOLD,24);
-	public static final int nbOfCols = 16;
+//	public static final int nbOfCols = 17;
 	private String aboutText = "";
 	
 	/**
@@ -185,9 +199,10 @@ public class JFractionLab extends JFrame implements ActionListener, ItemListener
 	 * @throws HeadlessException
 	 */
 	public JFractionLab() throws HeadlessException {
+		os = System.getProperty("os.name").toLowerCase();
 		setTitle("JFractionLab_version-number_lab");
 		setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
-	
+
 		lang.Messages.setLocale(lang.Messages.getLocale());
 		
 		//Menue
@@ -223,37 +238,46 @@ public class JFractionLab extends JFrame implements ActionListener, ItemListener
 		
 		jmWorkSheet.setText(lang.Messages.getString("worksheets"));
 
-//		jmiExtendingWorkSheet.addActionListener(this);
-//		jmiExtendingWorkSheet.setText(lang.Messages.getString("extend_fractions"));
-//		jmWorkSheet.add(jmiExtendingWorkSheet);
-//		
-//		jmiReducingWorkSheet.addActionListener(this);
-//		jmiReducingWorkSheet.setText(lang.Messages.getString("reduce_fractions"));
-//		jmWorkSheet.add(jmiReducingWorkSheet);
-//		
-//		jmiImproperFractionsWorkSheet.addActionListener(this);
-//		jmiImproperFractionsWorkSheet.setText(lang.Messages.getString("improper_fracs"));
-//		jmWorkSheet.add(jmiImproperFractionsWorkSheet);
-//		
-//		jmiMixedNumbersWorkSheet.addActionListener(this);
-//		jmiMixedNumbersWorkSheet.setText(lang.Messages.getString("mixed_numbers"));
-//		jmWorkSheet.add(jmiMixedNumbersWorkSheet);
-//		
-		jmiAdditionWorkSheet.addActionListener(this);
-		jmiAdditionWorkSheet.setText(lang.Messages.getString("add_fractions"));
-		jmWorkSheet.add(jmiAdditionWorkSheet);
-//		
-//		jmiSubtractionWorkSheet.addActionListener(this);
-//		jmiSubtractionWorkSheet.setText(lang.Messages.getString("minus_fractions"));
-//		jmWorkSheet.add(jmiSubtractionWorkSheet);
-//
-		jmiMultiplicationWorkSheet.addActionListener(this);
-		jmiMultiplicationWorkSheet.setText(lang.Messages.getString("multiply_fractions"));
-		jmWorkSheet.add(jmiMultiplicationWorkSheet);
-//		
-//		jmiDivisionWorkSheet.addActionListener(this);
-//		jmiDivisionWorkSheet.setText("neues wort!!");
-//		jmWorkSheet.add(jmiDivisionWorkSheet);
+		
+		jmiWorkSheetExtending.addActionListener(this);
+		jmiWorkSheetExtending.setText(lang.Messages.getString("extend_fractions"));
+		jmWorkSheet.add(jmiWorkSheetExtending);
+		
+		jmiWorkSheetReducing.addActionListener(this);
+		jmiWorkSheetReducing.setText(lang.Messages.getString("reduce_fractions"));
+		jmWorkSheet.add(jmiWorkSheetReducing);
+		
+		jmiWorkSheetImproperFractions.addActionListener(this);
+		jmiWorkSheetImproperFractions.setText(lang.Messages.getString("improper_fracs"));
+		jmWorkSheet.add(jmiWorkSheetImproperFractions);
+		
+		jmiWorkSheetMixedNumbers.addActionListener(this);
+		jmiWorkSheetMixedNumbers.setText(lang.Messages.getString("mixed_numbers"));
+		jmWorkSheet.add(jmiWorkSheetMixedNumbers);
+
+		jmiWorkSheetAddition.addActionListener(this);
+		jmiWorkSheetAddition.setText(lang.Messages.getString("add_fractions"));
+		jmWorkSheet.add(jmiWorkSheetAddition);
+
+		jmiWorkSheetSubtraction.addActionListener(this);
+		jmiWorkSheetSubtraction.setText(lang.Messages.getString("minus_fractions"));
+		jmWorkSheet.add(jmiWorkSheetSubtraction);
+
+		jmiWorkSheetMultiplication.addActionListener(this);
+		jmiWorkSheetMultiplication.setText(lang.Messages.getString("multiply_fractions"));
+		jmWorkSheet.add(jmiWorkSheetMultiplication);
+		
+		jmiWorkSheetDivision.addActionListener(this);
+		jmiWorkSheetDivision.setText(lang.Messages.getString("div_fr_by_fr"));
+		jmWorkSheet.add(jmiWorkSheetDivision);
+
+		if(os.contains("win")){
+			jmWorkSheet.addSeparator();
+			jmiConfigurePDFLatex = new JMenuItem();
+			jmiConfigurePDFLatex.addActionListener(this);
+			jmiConfigurePDFLatex.setText(lang.Messages.getString("configure_pdflatex"));
+			jmWorkSheet.add(jmiConfigurePDFLatex);
+		}
 		
 		jmHelp.setText(lang.Messages.getString("jmi_help"));
 		
@@ -282,8 +306,8 @@ public class JFractionLab extends JFrame implements ActionListener, ItemListener
 			TableLayout.FILL,
 		},{
 			//Zeilen
-			0.88/13*7,//pn_oben
-			0.88/13*6,//pn_unten
+			0.88/14*8,//pn_oben
+			0.88/14*6,//pn_unten
 			TableLayout.FILL,//pn_steuer
 		}};
 		
@@ -298,7 +322,8 @@ public class JFractionLab extends JFrame implements ActionListener, ItemListener
 			TableLayout.FILL,//3
 			TableLayout.FILL,//4
 			TableLayout.FILL,//5
-			TableLayout.FILL//6
+			TableLayout.FILL,//6
+			TableLayout.FILL//7
 		}};
 		double sizes_unten[][] = {{
 			// Spalten
@@ -345,32 +370,34 @@ public class JFractionLab extends JFrame implements ActionListener, ItemListener
 			btn_mixedNumbers.addActionListener(this);
 		pn_oben.add(btn_mixedNumbers, "0,6,1,6");
 		pn_oben.add(dsp_mixedNumbers, "2,6");
-		
+			btn_fractionToDecimal = new JButton("8. "+lang.Messages.getString("fraction_to_decimal"));
+			btn_fractionToDecimal.addActionListener(this);
+		pn_oben.add(btn_fractionToDecimal, "0,7,1,7");
+		pn_oben.add(dsp_fractionToDecimal, "2,7");
 		brd_top = new TitledBorder(new EtchedBorder(), lang.Messages.getString("learn_fractions"));
 		pn_oben.setBorder(brd_top);
 		cp.add(pn_oben, "0,0");
-		
-			btn_addFractions = new JButton("8. "+lang.Messages.getString("add_fractions"));
+			btn_addFractions = new JButton("9. "+lang.Messages.getString("add_fractions"));
 			btn_addFractions.addActionListener(this);
 		pn_unten.add(btn_addFractions, "0,0,1,0");
 		pn_unten.add(dsp_addFractions, "2,0");
-			btn_subtractFractions = new JButton("9. "+lang.Messages.getString("minus_fractions"));
+			btn_subtractFractions = new JButton("10. "+lang.Messages.getString("minus_fractions"));
 			btn_subtractFractions.addActionListener(this);
 		pn_unten.add(btn_subtractFractions, "0,1,1,1");
 		pn_unten.add(dsp_subtractFractions, "2,1");
-			btn_multiplyFractions = new JButton("10. "+lang.Messages.getString("multiply_fractions"));
+			btn_multiplyFractions = new JButton("11. "+lang.Messages.getString("multiply_fractions"));
 			btn_multiplyFractions.addActionListener(this);
 		pn_unten.add(btn_multiplyFractions, "0,2,1,2");
 		pn_unten.add(dsp_multiplyFractions, "2,2");
-			btn_divideFractionsByNumbers = new JButton("11. "+lang.Messages.getString("div_fr_by_nb"));
+			btn_divideFractionsByNumbers = new JButton("12. "+lang.Messages.getString("div_fr_by_nb"));
 			btn_divideFractionsByNumbers.addActionListener(this);
 		pn_unten.add(btn_divideFractionsByNumbers, "0,3,1,3");
 		pn_unten.add(dsp_divideFractionsByNumbers, "2,3");
-			btn_divideNumbersByFractions = new JButton("12. "+lang.Messages.getString("div_nb_by_fr"));
+			btn_divideNumbersByFractions = new JButton("13. "+lang.Messages.getString("div_nb_by_fr"));
 			btn_divideNumbersByFractions.addActionListener(this);
 		pn_unten.add(btn_divideNumbersByFractions, "0,4,1,4");
 		pn_unten.add(dsp_divideNumbersByFractions, "2,4");
-			btn_divideFractionsByFractions = new JButton("13. "+lang.Messages.getString("div_fr_by_fr"));
+			btn_divideFractionsByFractions = new JButton("14. "+lang.Messages.getString("div_fr_by_fr"));
 			btn_divideFractionsByFractions.addActionListener(this);
 		pn_unten.add(btn_divideFractionsByFractions, "0,5,1,5");
 		pn_unten.add(dsp_divideFractionsByFractions, "2,5");
@@ -388,8 +415,8 @@ public class JFractionLab extends JFrame implements ActionListener, ItemListener
 		pn_steuer.setBorder(new CompoundBorder(new EmptyBorder(1,1,1,1),new EtchedBorder() ));
 		cp.add(pn_steuer, "0,2");
 		
-		setLocation(50,50);
-		setSize(450, 600);
+		setLocation(400,50);
+		setSize(450, 650);
 		setMinimumSize(new Dimension(410, 460));
 		setResizable(true);
 		//JFrame.setDefaultLookAndFeelDecorated(true);
@@ -428,9 +455,12 @@ public class JFractionLab extends JFrame implements ActionListener, ItemListener
 	//		+ lang.Messages.getString("polish_translators")+"</li><li>"
 			//jredrejo@edu.juntaextremadura.net>
 			+ lang.Messages.getString("debian_package_maintainer")+"</li><li>"
-			+ lang.Messages.getString("icon_designer")+"</li></ul>"
+			+ lang.Messages.getString("icon_designer")+"</li><li>"
+			+"Darryl Burke, http://tips4java.wordpress.com</li><li>"
+			+"Daniel Barbalace, https://tablelayout.dev.java.net/</li></ul>"
 		;//String
-	}//Constructor
+		
+	}//constructor
 	
 	/**
 	 * 
@@ -459,6 +489,9 @@ public class JFractionLab extends JFrame implements ActionListener, ItemListener
 		}else if (prog == "gemischteZahlen"){
 			points_gemischteZahlen = p;
 			dsp_mixedNumbers.setText(String.valueOf(p));		
+		}else if (prog == "fractiontodecimal"){
+			points_fractionToDecimal = p;
+			dsp_fractionToDecimal.setText(String.valueOf(p));
 		}else if (prog == "addFractions"){
 			points_addFractions = p;
 			dsp_addFractions.setText(String.valueOf(p));
@@ -477,6 +510,8 @@ public class JFractionLab extends JFrame implements ActionListener, ItemListener
 		}else if (prog == "divideFractionsByFractions"){
 			points_divideFractionsByFractions = p;
 			dsp_divideFractionsByFractions.setText(String.valueOf(p));
+		}else{
+			throw new IllegalArgumentException();
 		}
 	}//public void setPoints(int p, String prog){
 	
@@ -495,43 +530,46 @@ public class JFractionLab extends JFrame implements ActionListener, ItemListener
 		jmiPortuguese.setText(lang.Messages.getString("portuguese"));
 //		jmiPolish.setText(lang.Messages.getString("polish"));
 		jmWorkSheet.setText(lang.Messages.getString("worksheets"));
-//		jmiExtendingWorkSheet.setText(lang.Messages.getString("extend_fractions"));
-//		jmiReducingWorkSheet.setText(lang.Messages.getString("reduce_fractions"));
-//		jmiImproperFractionsWorkSheet.setText(lang.Messages.getString("improper_fracs"));
-//		jmiMixedNumbersWorkSheet.setText(lang.Messages.getString("mixed_numbers"));
-		jmiAdditionWorkSheet.setText(lang.Messages.getString("add_fractions"));
-//		jmiSubtractionWorkSheet.setText(lang.Messages.getString("minus_fractions"));
-		jmiMultiplicationWorkSheet.setText(lang.Messages.getString("multiply_fractions"));
-//		jmiDivisionWorkSheet.setText(lang.Messages.getString(""));//TODO new snippet or three kinds of worksheets
-
+		jmiWorkSheetExtending.setText(lang.Messages.getString("extend_fractions"));
+		jmiWorkSheetReducing.setText(lang.Messages.getString("reduce_fractions"));
+		jmiWorkSheetImproperFractions.setText(lang.Messages.getString("improper_fracs"));
+		jmiWorkSheetMixedNumbers.setText(lang.Messages.getString("mixed_numbers"));
+		jmiWorkSheetAddition.setText(lang.Messages.getString("add_fractions"));
+		jmiWorkSheetSubtraction.setText(lang.Messages.getString("minus_fractions"));
+		jmiWorkSheetMultiplication.setText(lang.Messages.getString("multiply_fractions"));
+		jmiWorkSheetDivision.setText(lang.Messages.getString("div_fr_by_fr"));
+		if(os.contains("win")){
+			jmiConfigurePDFLatex.setText(lang.Messages.getString("configure_pdflatex"));
+		}
 		jmHelp.setText(lang.Messages.getString("Info"));
 		jmiHelp.setText(lang.Messages.getString("jmi_help"));
 		cb_showtippatstart.setText(lang.Messages.getString("show_hints_on_start"));
 		jmiAbout.setText(lang.Messages.getString("about_jfl"));
 		
 		brd_top.setTitle(lang.Messages.getString("learn_fractions"));
-		btn_clickNumerator.setText(lang.Messages.getString("click_numerator"));
-		btn_nameFraction.setText(lang.Messages.getString("name_fractions"));
-		btn_compareFractions.setText(lang.Messages.getString("compare_fractions"));
-		btn_extendFraction.setText(lang.Messages.getString("extend_fractions"));
-		btn_reduceFraction.setText(lang.Messages.getString("reduce_fractions"));
-		btn_improperFracions.setText(lang.Messages.getString("improper_fracs"));
-		btn_mixedNumbers.setText(lang.Messages.getString("mixed_numbers"));
-		
+		btn_clickNumerator.setText("1. "+lang.Messages.getString("click_numerator"));
+		btn_nameFraction.setText("2. "+lang.Messages.getString("name_fractions"));
+		btn_compareFractions.setText("3. "+lang.Messages.getString("compare_fractions"));
+		btn_extendFraction.setText("4. "+lang.Messages.getString("extend_fractions"));
+		btn_reduceFraction.setText("5. "+lang.Messages.getString("reduce_fractions"));
+		btn_improperFracions.setText("6. "+lang.Messages.getString("improper_fracs"));
+		btn_mixedNumbers.setText("7. "+lang.Messages.getString("mixed_numbers"));
+		btn_fractionToDecimal.setText("8. "+lang.Messages.getString("fraction_to_decimal"));
+
 		brd_bottom.setTitle(lang.Messages.getString("calculate_fractions"));
-		btn_addFractions.setText(lang.Messages.getString("add_fractions"));
-		btn_subtractFractions.setText(lang.Messages.getString("minus_fractions"));
-		btn_multiplyFractions.setText(lang.Messages.getString("multiply_fractions"));
-		btn_divideFractionsByNumbers.setText(lang.Messages.getString("div_fr_by_nb"));
-		btn_divideNumbersByFractions.setText(lang.Messages.getString("div_nb_by_fr"));
-		btn_divideFractionsByFractions.setText(lang.Messages.getString("div_fr_by_fr"));
+		btn_addFractions.setText("9. "+lang.Messages.getString("add_fractions"));
+		btn_subtractFractions.setText("10. "+lang.Messages.getString("minus_fractions"));
+		btn_multiplyFractions.setText("11. "+lang.Messages.getString("multiply_fractions"));
+		btn_divideFractionsByNumbers.setText("12. "+lang.Messages.getString("div_fr_by_nb"));
+		btn_divideNumbersByFractions.setText("13. "+lang.Messages.getString("div_nb_by_fr"));
+		btn_divideFractionsByFractions.setText("14. "+lang.Messages.getString("div_fr_by_fr"));
 		
 		btn_save.setText(lang.Messages.getString("save_results"));
 		btn_readTheLog.setText(lang.Messages.getString("read_logs"));
 	}//refreshCaption
 	
 	public static void setCheckBoxValue(){
-		if(new ConfManager().tippIsSet("tippatstart")){
+		if(new ConfManager().isTipAtStart()){
 			cb_showtippatstart.setSelected(true);
 		}else{
 			cb_showtippatstart.setSelected(false);
@@ -543,9 +581,9 @@ public class JFractionLab extends JFrame implements ActionListener, ItemListener
 		Object obj = e.getSource();
 		if (obj == cb_showtippatstart){
 			if(cb_showtippatstart.isSelected()){
-				new ConfManager().writeTippValueToConf("tippatstart",true);
+				new ConfManager().setTipAtStart(true);
 			}else{
-				new ConfManager().writeTippValueToConf("tippatstart",false);
+				new ConfManager().setTipAtStart(false);
 			}
 		}
 	}//itemStateChanged
@@ -569,6 +607,8 @@ public class JFractionLab extends JFrame implements ActionListener, ItemListener
         		new ImproperFraction(this,location_x, location_y, size_x, size_y+200);
         	}else if (obj == btn_mixedNumbers){
         		new MixedNumbers(this,location_x, location_y, size_x, size_y+200);
+        	}else if (obj == btn_fractionToDecimal){
+        		new FractionToDecimal(this,location_x, location_y, size_x, size_y+200);
         	}else if (obj == btn_addFractions){
         		new PlusAndMinus(this, "+", location_x, location_y, size_x + 100, size_y + 60);
         	}else if (obj == btn_subtractFractions){
@@ -590,6 +630,7 @@ public class JFractionLab extends JFrame implements ActionListener, ItemListener
         			points_reduceFraction,
         			points_unechteBrueche,
         			points_gemischteZahlen,
+        			points_fractionToDecimal,
         			points_addFractions,
         			points_subtractFractions,
         			points_multiplyFractions,
@@ -605,6 +646,7 @@ public class JFractionLab extends JFrame implements ActionListener, ItemListener
 	    			setPoints(0, "reduceFraction");
 	    			setPoints(0, "unechteBrueche");
 	    			setPoints(0, "gemischteZahlen");
+	    			setPoints(0, "fractiontodecimal");
 	    			setPoints(0, "addFractions");
 	    			setPoints(0, "subtractFractions");
 	    			setPoints(0, "multiplyFractions");
@@ -626,7 +668,24 @@ public class JFractionLab extends JFrame implements ActionListener, ItemListener
 			if (returnVal == JFileChooser.APPROVE_OPTION) {
 				File file = fc.getSelectedFile();
 				String[] dir = file.list(new MyFilenameFilter("jfl"));
-				Object[][] data = new Object[dir.length][nbOfCols];
+				String[] colnames = {
+						"Name","Date",
+						lang.Messages.getString("click_numerator"),
+						lang.Messages.getString("name_fractions"),
+						lang.Messages.getString("compare_fractions"),
+						lang.Messages.getString("extend_fractions"),
+						lang.Messages.getString("reduce_fractions"),
+						lang.Messages.getString("improper_fracs"),
+						lang.Messages.getString("mixed_numbers"),
+						lang.Messages.getString("fraction_to_decimal"),
+						lang.Messages.getString("add_fractions"),
+						lang.Messages.getString("minus_fractions"),
+						lang.Messages.getString("multiply_fractions"),
+						lang.Messages.getString("div_fr_by_nb"),
+						lang.Messages.getString("div_nb_by_fr"),
+						lang.Messages.getString("div_fr_by_fr")
+				};
+				String[][] data = new String[dir.length][colnames.length];
 				java.util.Arrays.sort(dir);
 				for(int i=0; i<dir.length; i++){
 					try{
@@ -636,19 +695,87 @@ public class JFractionLab extends JFrame implements ActionListener, ItemListener
 						is.close();
 						data[i][0] = sl.getPlayerName();
 						data[i][1] = sl.getTimeStamp();
-						data[i][2] = String.valueOf(sl.getPtsCN());
-						data[i][3] = String.valueOf(sl.getPtsNF());
-						data[i][4] = String.valueOf(sl.getPtsCF());
-						data[i][5] = String.valueOf(sl.getPtsEF());
-						data[i][6] = String.valueOf(sl.getPtsRF());
-						data[i][7] = String.valueOf(sl.getPtsIF());
-						data[i][8] = String.valueOf(sl.getPtsMN());
-						data[i][9] = String.valueOf(sl.getPtsPL());
-						data[i][10] = String.valueOf(sl.getPtsMIN());
-						data[i][11] = String.valueOf(sl.getPtsMF());
-						data[i][12] = String.valueOf(sl.getPtsDFN());
-						data[i][13] = String.valueOf(sl.getPtsDNF());
-						data[i][14] = String.valueOf(sl.getPtsDFF());
+						if(sl.getPtsCN() == 0){data[i][2] = " ";
+						}else{data[i][2] = String.valueOf(sl.getPtsCN());}
+						
+						if(sl.getPtsNF()==0){
+							data[i][3] = " ";
+						}else{
+							data[i][3] = String.valueOf(sl.getPtsNF());
+						}
+						
+						if(sl.getPtsCF()==0){
+							data[i][4] = " ";
+						}else{
+							data[i][4] = String.valueOf(sl.getPtsCF());
+						}
+						
+						if(sl.getPtsEF()==0){
+							data[i][5] = " ";
+						}else{
+							data[i][5] = String.valueOf(sl.getPtsEF());
+						}
+						
+						if(sl.getPtsRF()==0){
+							data[i][6] = " ";
+						}else{
+							data[i][6] = String.valueOf(sl.getPtsRF());
+						}
+						
+						if(sl.getPtsIF()==0){
+							data[i][7] = " ";
+						}else{
+							data[i][7] = String.valueOf(sl.getPtsIF());
+						}
+						
+						if(sl.getPtsMN()==0){
+							data[i][8] = " ";
+						}else{
+							data[i][8] = String.valueOf(sl.getPtsMN());
+						}
+						
+						if(sl.getPtsFtD()==0){
+							data[i][9] = " ";
+						}else{
+							data[i][9] = String.valueOf(sl.getPtsFtD());
+						}
+						
+						if(sl.getPtsPL()==0){
+							data[i][10] = " ";
+						}else{
+							data[i][10] = String.valueOf(sl.getPtsPL());
+						}
+						
+						if(sl.getPtsMIN()==0){
+							data[i][11] = " ";
+						}else{
+							data[i][11] = String.valueOf(sl.getPtsMIN());
+						}
+						
+						if(sl.getPtsMF()==0){
+							data[i][12] = " ";
+						}else{
+							data[i][12] = String.valueOf(sl.getPtsMF());
+						}
+						
+						if(sl.getPtsDFN()==0){
+							data[i][13] = " ";
+						}else{
+							data[i][13] = String.valueOf(sl.getPtsDFN());
+						}
+						
+						if(sl.getPtsDNF()==0){
+							data[i][14] = " ";
+						}else{
+							data[i][14] = String.valueOf(sl.getPtsDNF());
+						}
+						
+						if(sl.getPtsDFF()==0){
+							data[i][15] = " ";
+						}else{
+							data[i][15] = String.valueOf(sl.getPtsDFF());
+						}
+						
 					}catch( Exception ex ) {
 						ex.printStackTrace();
 						JOptionPane.showMessageDialog(
@@ -657,12 +784,7 @@ public class JFractionLab extends JFrame implements ActionListener, ItemListener
 						);
 					}//acatch
 				}//for
-				for (int as=0; as<dir.length; as++){
-					for(int is=0; is<nbOfCols; is++){
-						System.out.print("data:"+data[as][is]);
-					}
-				}//for
-				new LogTable(this, data);
+				new LogTable(this, data, colnames);
 			}//returnVal
 		}else if (obj == jmiGerman){
 			lang.Messages.setLocale(Locale.GERMAN);
@@ -687,33 +809,25 @@ public class JFractionLab extends JFrame implements ActionListener, ItemListener
 //			lang.Messages.setLocale(new Locale("pl"));
 //			refreshCaption();
 //		}
-//		else if(obj == jmiExtendingWorkSheet){
-//			//TODO implement this worksheet
-//			System.out.println("not yet implemented");
-//		}else if(obj == jmiReducingWorkSheet){
-//			//TODO implement this worksheet
-//			System.out.println("not yet implemented");
-//		}else if(obj == jmiImproperFractionsWorkSheet){
-//			//TODO implement this worksheet
-//			System.out.println("not yet implemented");
-//		}else if(obj == jmiMixedNumbersWorkSheet){
-//			//TODO implement this worksheet
-//			System.out.println("not yet implemented");
-//		}
-		else if(obj == jmiAdditionWorkSheet){
-			new AdditionWorkSheetDialog();
+		else if(obj == jmiWorkSheetExtending){
+			new WorkSheetDialogExtending();
+		}else if(obj == jmiWorkSheetReducing){
+			new WorkSheetDialogReducing();
+		}else if(obj == jmiWorkSheetImproperFractions){
+			new WorkSheetDialogImproperFractions();
+		}else if(obj == jmiWorkSheetMixedNumbers){
+			new WorkSheetDialogMixedNumbers();
+		}else if(obj == jmiWorkSheetAddition){
+			new WorkSheetDialogAddition();
+		}else if(obj == jmiWorkSheetSubtraction){
+			new WorkSheetDialogSubtraction();
+		}else if(obj == jmiWorkSheetMultiplication){
+			new WorkSheetDialogMultiplication();
+		}else if(obj == jmiWorkSheetDivision){
+			new WorkSheetDialogDivision();
+		}else if (obj == jmiConfigurePDFLatex){
+			new ConfigurePDFLATEXDialog();
 		}
-//		else if(obj == jmiSubtractionWorkSheet){
-//			//TODO implement this worksheet
-//			System.out.println("not yet implemented");
-//		}
-		else if(obj == jmiMultiplicationWorkSheet){
-			new MultiplicationWorksheetDialog();
-		}
-//		else if(obj == jmiDivisionWorkSheet){
-//			//TODO implement this worksheet
-//			System.out.println("not yet implemented");
-//		}
 		else if (obj == jmiHelp){
 			new HelpStarter(
 					lang.Messages.getLocale().toString(),
@@ -724,15 +838,15 @@ public class JFractionLab extends JFrame implements ActionListener, ItemListener
 		}//if else
 	}//actionPerformed
 	
-	public static int ggt(int a, int b){
+	public static int greatestCommonDivisor(int a, int b){
 		// verwendet wird der erweiterte Euklidsche Algorithmus
 		if(a==b||b==0) return a;
-		else return ggt(b,a%b);
+		else return greatestCommonDivisor(b,a%b);
 	}
 
-	public static int kgv(int a, int b){
+	public static int leastComonMultiple(int a, int b){
 		// verwendet wird der Satz ggT(a,b) * kgV(a,b) = a*b
-		return (a*b)/ggt(a,b);
+		return (a*b)/greatestCommonDivisor(a,b);
 	}
 	
 	
