@@ -15,7 +15,6 @@
  *	You should have received a copy of the GNU General Public License
  *	along with this program.  If not, see <http://www.gnu.org/licenses/>.
  **/
-
 package jfractionlab.exerciseDialogs;
 
 import info.clearthought.layout.TableLayout;
@@ -31,16 +30,16 @@ import java.awt.event.KeyListener;
 import javax.swing.JButton;
 import javax.swing.JLabel;
 
-import jfractionlab.ConfManager;
 import jfractionlab.FractionMaker;
 import jfractionlab.HelpStarter;
 import jfractionlab.JFractionLab;
 import jfractionlab.MyJTextField;
 import jfractionlab.displays.FractionAsRectangle;
-import jfractionlab.displays.FractionBar;
-import jfractionlab.jflOptionDialogs.MultiplicationWorksheetDialog;
-import jfractionlab.jflOptionDialogs.UsabilityDialog;
-import jfractionlab.jflOptionDialogs.WannaReduceQuestion;
+import jfractionlab.displays.FractionLine;
+import jfractionlab.jflDialogs.UsabilityDialog;
+import jfractionlab.jflDialogs.WannaReduceQuestion;
+import jfractionlab.jflDialogs.WorkSheetDialogMultiplication;
+import jfractionlab.worksheets.ExerciseMultDivision;
 
 
 
@@ -210,13 +209,13 @@ public class MultiplyFractions extends ExerciseDialog implements ActionListener,
 		content.add(lb_gleich1, "5,2");
 		JLabel lb_gleich2 = new JLabel("=", JLabel.CENTER);
 		content.add(lb_gleich2, "11,2");
-		FractionBar bs_fraction1 = new FractionBar();
+		FractionLine bs_fraction1 = new FractionLine();
 		content.add(bs_fraction1, "1,2");
-		FractionBar bs_fraction2 = new FractionBar();
+		FractionLine bs_fraction2 = new FractionLine();
 		content.add(bs_fraction2, "3,2");
-		FractionBar bs_fraction3 = new FractionBar();
+		FractionLine bs_fraction3 = new FractionLine();
 		content.add(bs_fraction3, "7,2,9,2");
-		FractionBar bs_fraction4 = new FractionBar();
+		FractionLine bs_fraction4 = new FractionLine();
 		content.add(bs_fraction4, "13,2");
 		//--Pizzen
 		content.add(pizza1, "0,5,1,5");
@@ -242,11 +241,7 @@ public class MultiplyFractions extends ExerciseDialog implements ActionListener,
 		String[] ar_howto = {
 			"howto_nb_and_enter","howto_option_type_of_exercise", "howto_option_reducing"
 		};
-		new UsabilityDialog(
-			"tippatstart",
-			ar_howto,
-			new ConfManager().tippIsSet("tippatstart")
-		);//new UsabilityDialog
+		new UsabilityDialog(ar_howto);//new UsabilityDialog
 	}//Konstruktor
 	
 	/**
@@ -256,14 +251,14 @@ public class MultiplyFractions extends ExerciseDialog implements ActionListener,
 	protected void makeProblem(){
 		//System.out.println("makeProblem");
 		if (smallNumbers){
-		brueche = new FractionMaker(9); //der Parameter setzt die exclusive Obergrenze der Zahlen des Bruches
+			brueche = new FractionMaker(9);//der Parameter setzt die exclusive Obergrenze der Zahlen des Bruches
 		}else{
 			brueche = new FractionMaker(17);
 		}
-		numerator1 = brueche.getZaehler_1();
-		denominator1 = brueche.getNenner_1();
-		numerator2 = brueche.getZaehler_2();
-		denominator2 = brueche.getNenner_2();
+		numerator1 = brueche.getNumerator_1();
+		denominator1 = brueche.getDenominator_1();
+		numerator2 = brueche.getNumerator_2();
+		denominator2 = brueche.getDenominator_2();
 		//Testzahlen
 		//numerator1 = 6;
 		//denominator1 = 9;
@@ -272,15 +267,16 @@ public class MultiplyFractions extends ExerciseDialog implements ActionListener,
 		//erster Bruch
 		tf_numerator1.setText(String.valueOf(numerator1));
 		tf_denominator1.setText(String.valueOf(denominator1));
-		pizza1.drawPizzaAsRectangle(numerator1, denominator1, Color.yellow, false);
+		pizza1.drawPizzaAsRectangle(numerator1, denominator1, Color.yellow, false,true);
+		//bla
 		//zweiter Bruch
 		tf_numerator2.setText(String.valueOf(numerator2));
 		tf_denominator2.setText(String.valueOf(denominator2));
-		pizza2.drawPizzaAsRectangle(numerator2, denominator2, Color.yellow, true);
+		pizza2.drawPizzaAsRectangle(numerator2, denominator2, Color.yellow, true,true);
 		//Rechnung:
 		tf_calculation_numerator1.setText(String.valueOf(numerator1));
 		tf_calculation_denominator1.setText(String.valueOf(denominator1));
-		calculation_pizza.drawPizzaAsRectangle(numerator1, denominator1, numerator2, denominator2, Color.yellow);
+		calculation_pizza.drawPizzaAsRectangle(numerator1, denominator1, numerator2, denominator2, Color.yellow,true);
 		//zweiter Bruch
 		tf_calculation_numerator2.setText(String.valueOf(numerator2));
 		tf_calculation_denominator2.setText(String.valueOf(denominator2));
@@ -291,13 +287,13 @@ public class MultiplyFractions extends ExerciseDialog implements ActionListener,
 			
 			//x x x
 			if(
-				JFractionLab.ggt(Integer.parseInt(tf_calculation_numerator1.getText()),Integer.parseInt(tf_calculation_denominator1.getText())) != 1
+				JFractionLab.greatestCommonDivisor(Integer.parseInt(tf_calculation_numerator1.getText()),Integer.parseInt(tf_calculation_denominator1.getText())) != 1
 				||
-				JFractionLab.ggt(Integer.parseInt(tf_calculation_numerator1.getText()),Integer.parseInt(tf_calculation_denominator2.getText())) != 1
+				JFractionLab.greatestCommonDivisor(Integer.parseInt(tf_calculation_numerator1.getText()),Integer.parseInt(tf_calculation_denominator2.getText())) != 1
 				||
-				JFractionLab.ggt(Integer.parseInt(tf_calculation_numerator2.getText()),Integer.parseInt(tf_calculation_denominator1.getText())) != 1
+				JFractionLab.greatestCommonDivisor(Integer.parseInt(tf_calculation_numerator2.getText()),Integer.parseInt(tf_calculation_denominator1.getText())) != 1
 				||
-				JFractionLab.ggt(Integer.parseInt(tf_calculation_numerator2.getText()),Integer.parseInt(tf_calculation_denominator2.getText())) != 1
+				JFractionLab.greatestCommonDivisor(Integer.parseInt(tf_calculation_numerator2.getText()),Integer.parseInt(tf_calculation_denominator2.getText())) != 1
 			){
 				new WannaReduceQuestion(this);
 			}
@@ -317,13 +313,13 @@ public class MultiplyFractions extends ExerciseDialog implements ActionListener,
 	 *
 	 */
  	private void checkReducability(){
-		if(JFractionLab.ggt(Integer.parseInt(tf_calculation_numerator1.getText()),Integer.parseInt(tf_calculation_denominator1.getText())) != 1){
+		if(JFractionLab.greatestCommonDivisor(Integer.parseInt(tf_calculation_numerator1.getText()),Integer.parseInt(tf_calculation_denominator1.getText())) != 1){
 			initReductionProcess(1,1);
-		}else if(JFractionLab.ggt(Integer.parseInt(tf_calculation_numerator1.getText()),Integer.parseInt(tf_calculation_denominator2.getText())) != 1){
+		}else if(JFractionLab.greatestCommonDivisor(Integer.parseInt(tf_calculation_numerator1.getText()),Integer.parseInt(tf_calculation_denominator2.getText())) != 1){
 			initReductionProcess(1,2);
-		}else if(JFractionLab.ggt(Integer.parseInt(tf_calculation_numerator2.getText()),Integer.parseInt(tf_calculation_denominator1.getText())) != 1){
+		}else if(JFractionLab.greatestCommonDivisor(Integer.parseInt(tf_calculation_numerator2.getText()),Integer.parseInt(tf_calculation_denominator1.getText())) != 1){
 			initReductionProcess(2,1);
-		}else if(JFractionLab.ggt(Integer.parseInt(tf_calculation_numerator2.getText()),Integer.parseInt(tf_calculation_denominator2.getText())) != 1){
+		}else if(JFractionLab.greatestCommonDivisor(Integer.parseInt(tf_calculation_numerator2.getText()),Integer.parseInt(tf_calculation_denominator2.getText())) != 1){
 			initReductionProcess(2,2);
 		}else{
 			//System.out.println("checkReducability(): nichts ist teilbar");
@@ -430,7 +426,7 @@ public class MultiplyFractions extends ExerciseDialog implements ActionListener,
 			smallNumbers = false;
 			nextProblem();
 		}else if(obj == jmiCreateWorkSheet){
-			new MultiplicationWorksheetDialog();
+			new WorkSheetDialogMultiplication();
 		}else if(obj == jmiHelp){
 			new HelpStarter(
 					lang.Messages.getLocale().toString(),
@@ -452,14 +448,14 @@ public class MultiplyFractions extends ExerciseDialog implements ActionListener,
 		}else if(obj == btn_end & key == KeyEvent.VK_ENTER){
 			close_it();
 		}else if(obj == tf_numerator1 & key == KeyEvent.VK_ENTER){
-			if(readInputNumber(tf_numerator1) != null){
+			if(readInputInt(tf_numerator1) != null){
 				numerator1 = Integer.parseInt(tf_numerator1.getText());
 				tf_numerator1.setEditable(false);
 				tf_denominator1.setEditable(true);
 				tf_denominator1.requestFocusInWindow();
 			}//if(readInputNumber(tf_numerator1)
 		}else if(obj == tf_denominator1 & key == KeyEvent.VK_ENTER){
-			if(readInputNumber(tf_denominator1) != null){
+			if(readInputInt(tf_denominator1) != null){
 				int pn = Integer.parseInt(tf_denominator1.getText());
 				if(pn <= numerator1){
 					lb_info.setText(lang.Messages.getString("dn_must_be_bigger"));
@@ -471,20 +467,20 @@ public class MultiplyFractions extends ExerciseDialog implements ActionListener,
 				}else{
 					denominator1 = pn;
 					tf_denominator1.setEditable(false);
-					pizza1.drawPizzaAsRectangle(numerator1, denominator1, Color.yellow, false);
+					pizza1.drawPizzaAsRectangle(numerator1, denominator1, Color.yellow, false,true);
 					tf_numerator2.setEditable(true);
 					tf_numerator2.requestFocusInWindow();
 				}
 			}//if(readInputNumber(tf_denominator1)
 		}else if(obj == tf_numerator2 & key == KeyEvent.VK_ENTER){
-			if(readInputNumber(tf_numerator2) != null){
+			if(readInputInt(tf_numerator2) != null){
 				numerator2 = Integer.parseInt(tf_numerator2.getText());
 				tf_numerator2.setEditable(false);
 				tf_denominator2.setEditable(true);
 				tf_denominator2.requestFocusInWindow();
 			}//if(readInputNumber(tf_numerator2)
 		}else if(obj == tf_denominator2 & key == KeyEvent.VK_ENTER){
-			if(readInputNumber(tf_denominator2) != null){
+			if(readInputInt(tf_denominator2) != null){
 				int pn = Integer.parseInt(tf_denominator2.getText());
 				if(pn <= numerator2){
 					lb_info.setText(lang.Messages.getString("dn_must_be_bigger"));
@@ -496,10 +492,10 @@ public class MultiplyFractions extends ExerciseDialog implements ActionListener,
 				}else{
 					denominator2 = pn;
 					tf_denominator2.setEditable(false);
-					pizza2.drawPizzaAsRectangle(numerator2, denominator2, Color.yellow, true);
+					pizza2.drawPizzaAsRectangle(numerator2, denominator2, Color.yellow, true,true);
 					tf_calculation_numerator1.setText(String.valueOf(numerator1));
 					tf_calculation_denominator1.setText(String.valueOf(denominator1));
-					calculation_pizza.drawPizzaAsRectangle(numerator1, denominator1, numerator2, denominator2, Color.yellow);
+					calculation_pizza.drawPizzaAsRectangle(numerator1, denominator1, numerator2, denominator2, Color.yellow,true);
 					tf_calculation_numerator2.setText(String.valueOf(numerator2));
 					tf_calculation_denominator2.setText(String.valueOf(denominator2));
 					if(bl_with_reducing){
@@ -511,19 +507,19 @@ public class MultiplyFractions extends ExerciseDialog implements ActionListener,
 				}
 			}//if(readInputNumber(tf_denominator2)
 		}else if(obj == tf_reduced_numerator1 & key == KeyEvent.VK_ENTER){
-			if(readInputNumber(tf_reduced_numerator1) != null){
+			if(readInputInt(tf_reduced_numerator1) != null){
 					tf_reductionprocess_outer_denominator.requestFocusInWindow();
 			}
 		}else if(obj == tf_reduced_denominator1 & key == KeyEvent.VK_ENTER){
-			if(readInputNumber(tf_reduced_denominator1) != null){
+			if(readInputInt(tf_reduced_denominator1) != null){
 					tf_reduceprocess_denominator_Action();
 			}
 		}else if(obj == tf_reduced_numerator2 & key == KeyEvent.VK_ENTER){
-			if(readInputNumber(tf_reduced_numerator2) != null){
+			if(readInputInt(tf_reduced_numerator2) != null){
 					tf_reductionprocess_outer_denominator.requestFocusInWindow();
 			}
 		}else if(obj == tf_reduced_denominator2 & key == KeyEvent.VK_ENTER){
-			if(readInputNumber(tf_reduced_denominator2) != null){
+			if(readInputInt(tf_reduced_denominator2) != null){
 				int z = Integer.parseInt(tf_reduced_denominator2.getText());
 				if (z == 0){
 					tf_reduced_denominator2.setText("");
@@ -533,7 +529,7 @@ public class MultiplyFractions extends ExerciseDialog implements ActionListener,
 				}
 			}
 		}else if(obj == tf_endresult_numerator & key == KeyEvent.VK_ENTER){
-			if(readInputNumber(tf_endresult_numerator) != null){
+			if(readInputInt(tf_endresult_numerator) != null){
 				int z1 = Integer.parseInt(tf_calculation_numerator1.getText());
 				int z2 = Integer.parseInt(tf_calculation_numerator2.getText());
 				int zz = Integer.parseInt(tf_endresult_numerator.getText());
@@ -549,7 +545,7 @@ public class MultiplyFractions extends ExerciseDialog implements ActionListener,
 				}
 			}
 		}else if(obj == tf_endresult_denominator & key == KeyEvent.VK_ENTER){
-			if(readInputNumber(tf_endresult_denominator) != null){
+			if(readInputInt(tf_endresult_denominator) != null){
 				int cn1 = Integer.parseInt(tf_calculation_numerator1.getText());
 				int cn2 = Integer.parseInt(tf_calculation_numerator2.getText());
 				int cd1 = Integer.parseInt(tf_calculation_denominator1.getText()); 
@@ -562,9 +558,9 @@ public class MultiplyFractions extends ExerciseDialog implements ActionListener,
 				}else{
 					tf_endresult_denominator.setEditable(false);
 					if(cn1 < cd1 && cn2 < cd2){
-						endresult_pizza.drawPizzaAsRectangle(cn1, cd1, cn2, cd2, Color.yellow);
+						endresult_pizza.drawPizzaAsRectangle(cn1, cd1, cn2, cd2, Color.yellow,true);
 					}else{
-						endresult_pizza.drawPizzaAsRectangle(ez, en, Color.yellow, false);
+						endresult_pizza.drawPizzaAsRectangle(ez, en, Color.yellow, false,true);
 					}
 					if(bl_randomProblem){
 						points++;
@@ -624,13 +620,13 @@ public class MultiplyFractions extends ExerciseDialog implements ActionListener,
 			lb_info.setText("dieser fehler sollte eigentlich unmoeglich sein!");
 			lbnbOK = false;
 		}
-		if(readInputNumber(tf_reductionprocess_outer_denominator) != null && lbnbOK){
+		if(readInputInt(tf_reductionprocess_outer_denominator) != null && lbnbOK){
 			z_neu = Integer.parseInt(tf_reductionprocess_outer_numerator.getText());
 			n_neu = Integer.parseInt(tf_reductionprocess_outer_denominator.getText());
 			//System.out.println("tf_reduceprocess_denominator_FocusLost: z/z_neu/n/n_neu"+z+"/"+z_neu+"/"+n+"/"+n_neu);
 			//sind z o n vielfache oder teiler??
 			if(inRow(z,z_neu) && inRow(n,n_neu)){
-				if(JFractionLab.ggt(z_neu,n_neu) != 1 || z/z_neu != n/n_neu){ //Es kann weitergekrzt werden
+				if(JFractionLab.greatestCommonDivisor(z_neu,n_neu) != 1 || z/z_neu != n/n_neu){ //Es kann weitergekrzt werden
 					if(z/z_neu != n/n_neu){//reduction is wrong
 						lb_info.setText(lang.Messages.getString("div_by_same_factor"));
 					}else{//reduction is right but not optimal
