@@ -16,6 +16,7 @@
  *	along with this program.  If not, see <http://www.gnu.org/licenses/>.
  **/
 
+
 package jfractionlab.exerciseDialogs;
 
 import info.clearthought.layout.TableLayout;
@@ -35,10 +36,13 @@ import jfractionlab.HelpStarter;
 import jfractionlab.JFractionLab;
 import jfractionlab.MyJTextField;
 import jfractionlab.displays.FractionAsCircle;
-import jfractionlab.displays.FractionBar;
-import jfractionlab.jflOptionDialogs.UsabilityDialog;
-import jfractionlab.jflOptionDialogs.WannaFindBestCommonDenominator;
-import jfractionlab.jflOptionDialogs.WannaReduceQuestion;
+import jfractionlab.displays.FractionLine;
+import jfractionlab.jflDialogs.UsabilityDialog;
+import jfractionlab.jflDialogs.WannaFindBestCommonDenominator;
+import jfractionlab.jflDialogs.WannaReduceQuestion;
+import jfractionlab.jflDialogs.WorkSheetDialogAddition;
+import jfractionlab.jflDialogs.WorkSheetDialogMultiplication;
+import jfractionlab.jflDialogs.WorkSheetDialogSubtraction;
 
 
 public class PlusAndMinus extends ExerciseDialog implements ActionListener, KeyListener{
@@ -115,6 +119,11 @@ public class PlusAndMinus extends ExerciseDialog implements ActionListener, KeyL
 		rb_reducing.addActionListener(this);
 		jmOptions.add(rb_reducing);
 		jmb.add(jmOptions);
+		
+		jmiCreateWorkSheet.addActionListener(this);
+		jmWorkSheet.add(jmiCreateWorkSheet);
+		jmb.add(jmWorkSheet);
+		
 		jmiHelp.addActionListener(this);
 		jmb.add(jmHelp);
 		setJMenuBar(jmb);
@@ -152,11 +161,11 @@ public class PlusAndMinus extends ExerciseDialog implements ActionListener, KeyL
         	addTextField(tf_calculation_numerator1);
 			tf_calculation_numerator1.addKeyListener(this);
 			tf_calculation_numerator1.setEditable(false);
-		content.add(tf_calculation_numerator1, "7,0,r,b");
+		content.add(tf_calculation_numerator1, "7,0,c,b");
 			addTextField(tf_calculation_numerator2);
 			tf_calculation_numerator2.addKeyListener(this);
 			tf_calculation_numerator2.setEditable(false);
-		content.add(tf_calculation_numerator2, "10,0,l,b");
+		content.add(tf_calculation_numerator2, "10,0,c,b");
 			addTextField(tf_provisionalresult_numerator);
 			tf_provisionalresult_numerator.addKeyListener(this);
 			tf_provisionalresult_numerator.setEditable(false);
@@ -176,9 +185,9 @@ public class PlusAndMinus extends ExerciseDialog implements ActionListener, KeyL
 		content.add(tf_denominator2, "4,2,c,t");
 			addTextField(tf_calculation_denominator1);
 			tf_calculation_denominator1.addKeyListener(this);
-		content.add(tf_calculation_denominator1, "7,2,r,b");
+		content.add(tf_calculation_denominator1, "7,2,c,t");
 			addTextField(tf_calculation_denominator2);
-		content.add(tf_calculation_denominator2, "10,2,l,b");
+		content.add(tf_calculation_denominator2, "10,2,c,t");
 		content.add(tf_provisionalresult_denominator, "13,2,c,t");
 			addTextField(tf_endresult_denominator);
 			tf_endresult_denominator.addKeyListener(this);
@@ -190,10 +199,8 @@ public class PlusAndMinus extends ExerciseDialog implements ActionListener, KeyL
 		content.add(lb_aufgabenPlus, "2,1,3,1");
        			JLabel lb_aufgabenPizza = new JLabel(operator, JLabel.CENTER);
 		content.add(lb_aufgabenPizza, "2,3,3,3");
-			JLabel lb_calculationNominatorPlus = new JLabel(operator, JLabel.CENTER);
-		content.add(lb_calculationNominatorPlus, "8,0,9,0,c,b");
-			JLabel lb_calculationDenominatorPlus = new JLabel(operator, JLabel.CENTER);
-		content.add(lb_calculationDenominatorPlus, "8,2,9,2,c,b");
+		JLabel lb_calculationPlus = new JLabel(operator, JLabel.CENTER);
+		content.add(lb_calculationPlus, "8,1,9,1,c,b");
 		
 			JLabel lb_calculationPizza = new JLabel(operator, JLabel.CENTER);
 		content.add(lb_calculationPizza, "8,3,9,3");
@@ -209,15 +216,17 @@ public class PlusAndMinus extends ExerciseDialog implements ActionListener, KeyL
 		content.add(lb_rundungsGleich, "14,1,15,1");
 		content.add(lb_equalsign_endresult, "14,3,15,3");
 		
-			FractionBar bs_fraction1 = new FractionBar();
+			FractionLine bs_fraction1 = new FractionLine();
 		content.add(bs_fraction1, "1,1");
-			FractionBar bs_fraction2 = new FractionBar();
-        	content.add(bs_fraction2, "4,1");
-			FractionBar bs_rechnung = new FractionBar();
-		content.add(bs_rechnung, "7,1,10,1");
-			FractionBar bs_ergebnis = new FractionBar();
+			FractionLine bs_fraction2 = new FractionLine();
+		content.add(bs_fraction2, "4,1");
+			FractionLine bs_rechnung1 = new FractionLine();
+		content.add(bs_rechnung1, "7,1");
+			FractionLine bs_rechnung2 = new FractionLine();
+		content.add(bs_rechnung2, "10,1");
+			FractionLine bs_ergebnis = new FractionLine();
 		content.add(bs_ergebnis, "13,1");
-			FractionBar bs_gerundetesErgebnis = new FractionBar();
+			FractionLine bs_gerundetesErgebnis = new FractionLine();
         	content.add(bs_gerundetesErgebnis, "17,1");
 
 		//--Pizzen
@@ -255,11 +264,7 @@ public class PlusAndMinus extends ExerciseDialog implements ActionListener, KeyL
 		String[] ar_howto = {
 				"howto_nb_and_enter","howto_option_type_of_exercise", "howto_option_reducing"
 			};
-		new UsabilityDialog(
-			"tippatstart",
-			ar_howto,
-			new ConfManager().tippIsSet("tippatstart")
-		);//new UsabilityDialog
+		new UsabilityDialog(ar_howto);//new UsabilityDialog
 	}//Konstruktor
 
 	/**
@@ -269,17 +274,17 @@ public class PlusAndMinus extends ExerciseDialog implements ActionListener, KeyL
 	protected void makeProblem(){
 		if(operator.equals("+")){
 			fraction = new FractionMaker(10); //der Parameter setzt die exclusive Obergrenze der Zahlen des Bruches
-			numerator1 = fraction.getZaehler_1();
-			denominator1 = fraction.getNenner_1();
-			numerator2 = fraction.getZaehler_2();
-			denominator2 = fraction.getNenner_2();
+			numerator1 = fraction.getNumerator_1();
+			denominator1 = fraction.getDenominator_1();
+			numerator2 = fraction.getNumerator_2();
+			denominator2 = fraction.getDenominator_2();
 		}else if (operator.equals("-")){
 			do{ 
 				fraction = new FractionMaker(10);
-				numerator1 = fraction.getZaehler_1();
-				denominator1 = fraction.getNenner_1();
-				numerator2 = fraction.getZaehler_2();
-				denominator2 = fraction.getNenner_2();
+				numerator1 = fraction.getNumerator_1();
+				denominator1 = fraction.getDenominator_1();
+				numerator2 = fraction.getNumerator_2();
+				denominator2 = fraction.getDenominator_2();
 			}while(!((float)numerator1/denominator1 > (float)numerator2/denominator2));
 		}
 		//Testzahlen
@@ -377,7 +382,15 @@ public class PlusAndMinus extends ExerciseDialog implements ActionListener, KeyL
 			//it should switch to "no reduce-mode"
 			bl_with_reducing = false;
 			nextProblem();
-		}else if(obj == jmiHelp){
+		}
+		else if(obj == jmiCreateWorkSheet){
+			if(operator.equals("+")){
+				new WorkSheetDialogAddition();
+			}else{
+				new WorkSheetDialogSubtraction();
+			}
+		}
+		else if(obj == jmiHelp){
 			if(operator.equals("+")){
 				new HelpStarter(
 						lang.Messages.getLocale().toString(),
@@ -401,15 +414,15 @@ public class PlusAndMinus extends ExerciseDialog implements ActionListener, KeyL
 		int key = event.getKeyCode();
 		lb_info.setText("");
 		if (obj == tf_numerator1 & key == KeyEvent.VK_ENTER){
-			if ( readInputNumber(tf_numerator1) != null){
-				numerator1 = readInputNumber(tf_numerator1);
+			if ( readInputInt(tf_numerator1) != null){
+				numerator1 = readInputInt(tf_numerator1);
 				tf_numerator1.setEditable(false);
 				tf_denominator1.setEditable(true);
 				tf_denominator1.requestFocusInWindow();
 			}
 		}else if(obj == tf_denominator1 & key == KeyEvent.VK_ENTER){
-			if ( readInputNumber(tf_denominator1) != null){
-				int pn = readInputNumber(tf_denominator1);
+			if ( readInputInt(tf_denominator1) != null){
+				int pn = readInputInt(tf_denominator1);
 				if(pn <= numerator1){
 					lb_info.setText(lang.Messages.getString("dn_must_be_bigger"));
 					tf_denominator1.setText("");
@@ -426,15 +439,15 @@ public class PlusAndMinus extends ExerciseDialog implements ActionListener, KeyL
 				}
 			}//if ( readInputNumber() != null)
 		}else if (obj == tf_numerator2 & key == KeyEvent.VK_ENTER){
-			if ( readInputNumber(tf_numerator2) != null){
-				numerator2 = readInputNumber(tf_numerator2);
+			if ( readInputInt(tf_numerator2) != null){
+				numerator2 = readInputInt(tf_numerator2);
 				tf_numerator2.setEditable(false);
 				tf_denominator2.setEditable(true);
 				tf_denominator2.requestFocusInWindow();
 			}//if ( readInputNumber() != null)
 		}else if(obj == tf_denominator2 & key == KeyEvent.VK_ENTER){
-			if ( readInputNumber(tf_denominator2) != null){
-				int pn = readInputNumber(tf_denominator2);
+			if ( readInputInt(tf_denominator2) != null){
+				int pn = readInputInt(tf_denominator2);
 				if(pn <= numerator2){
 					lb_info.setText(lang.Messages.getString("dn_must_be_bigger"));
 					tf_denominator2.setText("");
@@ -471,8 +484,8 @@ public class PlusAndMinus extends ExerciseDialog implements ActionListener, KeyL
 				}
 			}//if ( readInputNumber() != null)
 		}else if (obj == tf_calculation_denominator1 & key == KeyEvent.VK_ENTER){
-			if ( readInputNumber(tf_calculation_denominator1) != null){
-				int rn = readInputNumber(tf_calculation_denominator1);
+			if ( readInputInt(tf_calculation_denominator1) != null){
+				int rn = readInputInt(tf_calculation_denominator1);
 				if (!checkCommonDenominator(rn)){
 					// common denominator is NOT right
 					calculation_pizza_1.drawPizzaAsCircle(
@@ -489,7 +502,7 @@ public class PlusAndMinus extends ExerciseDialog implements ActionListener, KeyL
 					lb_info.setText(lang.Messages.getString("cd_is_leastcommonmultiple"));
 				}else{
 					//System.out.println("common denominator is right");
-					if(rn != JFractionLab.kgv(denominator1, denominator2)){
+					if(rn != JFractionLab.leastComonMultiple(denominator1, denominator2)){
 						new WannaFindBestCommonDenominator(this);
 					}else{
 						continueWithThisCommonDenominator(rn);
@@ -504,8 +517,8 @@ public class PlusAndMinus extends ExerciseDialog implements ActionListener, KeyL
 				}
 			}//if ( readInputNumber() != null)
 		}else if (obj == tf_calculation_numerator1 & key == KeyEvent.VK_ENTER){
-			if ( readInputNumber(tf_calculation_numerator1) != null){
-				int cn1 = readInputNumber(tf_calculation_numerator1);
+			if ( readInputInt(tf_calculation_numerator1) != null){
+				int cn1 = readInputInt(tf_calculation_numerator1);
 				int xx = numerator1 * common_denominator / denominator1;
 				if(cn1 != xx ){
 					//System.out.println("xx nicht OK");
@@ -531,8 +544,8 @@ public class PlusAndMinus extends ExerciseDialog implements ActionListener, KeyL
 				}
 			}//if ( readInputNumber() != null)
 		}else if (obj == tf_calculation_numerator2 & key == KeyEvent.VK_ENTER){
-			if ( readInputNumber(tf_calculation_numerator2) != null){
-				int cn2 = readInputNumber(tf_calculation_numerator2);
+			if ( readInputInt(tf_calculation_numerator2) != null){
+				int cn2 = readInputInt(tf_calculation_numerator2);
 				int xx =  numerator2 * common_denominator / denominator2;
 				if(cn2 != xx){
 					if(operator.equals("+")){
@@ -583,8 +596,8 @@ public class PlusAndMinus extends ExerciseDialog implements ActionListener, KeyL
 		}else if (obj == tf_provisionalresult_numerator & key == KeyEvent.VK_ENTER){
 			tf_provisionalresult_numerator_FocusLost();
 		}else if (obj == tf_endresult_numerator & key == KeyEvent.VK_ENTER){
-			if ( readInputNumber(tf_endresult_numerator) != null){
-				endresult_numerator = readInputNumber(tf_endresult_numerator);
+			if ( readInputInt(tf_endresult_numerator) != null){
+				endresult_numerator = readInputInt(tf_endresult_numerator);
 				//it is only checked that the numerator is not too big
 				//anything else is checked in the "tf_endresult_denominator"-chapter
 				int num = 0;
@@ -608,9 +621,9 @@ public class PlusAndMinus extends ExerciseDialog implements ActionListener, KeyL
 				}
 			}//if ( readInputNumber() != null)
 		}else if (obj == tf_endresult_denominator & key == KeyEvent.VK_ENTER){
-			if ( readInputNumber(tf_endresult_denominator) != null){
-				int endresult_denominator = readInputNumber(tf_endresult_denominator);
-				int ggt = JFractionLab.ggt(provisionalresult_numerator , common_denominator);
+			if ( readInputInt(tf_endresult_denominator) != null){
+				int endresult_denominator = readInputInt(tf_endresult_denominator);
+				int ggt = JFractionLab.greatestCommonDivisor(provisionalresult_numerator , common_denominator);
 				
 				//denominator : reduction is optimal
 				if(endresult_denominator == common_denominator / ggt){
@@ -666,8 +679,8 @@ public class PlusAndMinus extends ExerciseDialog implements ActionListener, KeyL
 		tf_calculation_numerator1.requestFocusInWindow();
 	}
 	private void tf_provisionalresult_numerator_FocusLost(){
-		if ( readInputNumber(tf_provisionalresult_numerator) != null){
-			int prn = readInputNumber(tf_provisionalresult_numerator);
+		if ( readInputInt(tf_provisionalresult_numerator) != null){
+			int prn = readInputInt(tf_provisionalresult_numerator);
 			int result = 0;
 			if(operator.equals("+")){
 				result = calculation_numerator1 + calculation_numerator2;
@@ -711,11 +724,11 @@ public class PlusAndMinus extends ExerciseDialog implements ActionListener, KeyL
 				if(bl_with_reducing){
 					reduce_this_problem(prn);
 				}else{ //ohne kuerzen
-					System.out.println("ggt = "+JFractionLab.ggt(prn, common_denominator));
+					System.out.println("ggt = "+JFractionLab.greatestCommonDivisor(prn, common_denominator));
 					System.out.println("prn != common_denominator ?? =" +
 							prn+", "+common_denominator);
 					if(
-							JFractionLab.ggt(prn, common_denominator) != 1
+							JFractionLab.greatestCommonDivisor(prn, common_denominator) != 1
 							||
 							prn > common_denominator
 						){
@@ -766,7 +779,7 @@ public class PlusAndMinus extends ExerciseDialog implements ActionListener, KeyL
 			tf_endresult_numerator.requestFocusInWindow();
 		}else{ //Ergebnis ist nicht groesser als 1
 			//Wenn das Ergebnis nicht weiter zu kuerzen ist
-			if(JFractionLab.ggt(provisionalresult_numerator, common_denominator) == 1){
+			if(JFractionLab.greatestCommonDivisor(provisionalresult_numerator, common_denominator) == 1){
 				if(bl_randomProblem){points++;};
 				lb_info.setText(lang.Messages.getString("that_is_right"));
 				pdsp.setText(String.valueOf(points));
